@@ -1,7 +1,7 @@
 /*
  * This file is part of the QPackageKit project
  * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
- * Copyright (C) 2010-2016 Daniel Nicoletti <dantti12@gmail.com>
+ * Copyright (C) 2010-2018 Daniel Nicoletti <dantti12@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -27,10 +27,74 @@
 #include "common.h"
 
 Q_LOGGING_CATEGORY(PACKAGEKITQT_DAEMON, "packagekitqt.daemon")
+Q_LOGGING_CATEGORY(PACKAGEKITQT_OFFLINE, "packagekitqt.offline")
+
+Q_DECLARE_METATYPE(PackageKit::PkPackage);
+Q_DECLARE_METATYPE(QList<PackageKit::PkPackage>);
+Q_DECLARE_METATYPE(PackageKit::PkDetail);
+Q_DECLARE_METATYPE(QList<PackageKit::PkDetail>);
+
+const QDBusArgument &operator<<(QDBusArgument &argument, const PackageKit::PkPackage &pkg)
+{
+    argument.beginStructure();
+    argument << pkg.info;
+    argument << pkg.pid;
+    argument << pkg.summary;
+    argument.endStructure();
+    return argument;
+}
+
+const QDBusArgument &operator>>(const QDBusArgument &argument, PackageKit::PkPackage &pkg)
+{
+    argument.beginStructure();
+    argument >> pkg.info;
+    argument >> pkg.pid;
+    argument >> pkg.summary;
+    argument.endStructure();
+    return argument;
+}
+
+const QDBusArgument &operator>>(const QDBusArgument &argument, PackageKit::PkDetail &detail)
+{
+    argument.beginStructure();
+    argument >> detail.package_id;
+    argument >> detail.updates;
+    argument >> detail.obsoletes;
+    argument >> detail.vendor_urls;
+    argument >> detail.bugzilla_urls;
+    argument >> detail.cve_urls;
+    argument >> detail.restart;
+    argument >> detail.update_text;
+    argument >> detail.changelog;
+    argument >> detail.state;
+    argument >> detail.issued;
+    argument >> detail.updated;
+    argument.endStructure();
+    return argument;
+}
+
+const QDBusArgument &operator<<(QDBusArgument &argument, const PackageKit::PkDetail &detail)
+{
+    argument.beginStructure();
+    argument << detail.package_id;
+    argument << detail.updates;
+    argument << detail.obsoletes;
+    argument << detail.vendor_urls;
+    argument << detail.bugzilla_urls;
+    argument << detail.cve_urls;
+    argument << detail.restart;
+    argument << detail.update_text;
+    argument << detail.changelog;
+    argument << detail.state;
+    argument << detail.issued;
+    argument << detail.updated;
+    argument.endStructure();
+    return argument;
+}
 
 using namespace PackageKit;
 
-Daemon* Daemon::m_global = 0;
+Daemon* Daemon::m_global = nullptr;
 
 Daemon* Daemon::global()
 {
@@ -46,20 +110,25 @@ Daemon::Daemon(QObject *parent) :
     d_ptr(new DaemonPrivate(this))
 {
     Q_D(Daemon);
-    d->daemon = new ::OrgFreedesktopPackageKitInterface(QLatin1String(PK_NAME),
-                                                        QLatin1String(PK_PATH),
+    d->daemon = new ::OrgFreedesktopPackageKitInterface(PK_NAME,
+                                                        PK_PATH,
                                                         QDBusConnection::systemBus(),
                                                         this);
 
-    QDBusConnection::systemBus().connect(QLatin1String(PK_NAME),
-                                         QLatin1String(PK_PATH),
-                                         QLatin1String(DBUS_PROPERTIES),
+    QDBusConnection::systemBus().connect(PK_NAME,
+                                         PK_PATH,
+                                         DBUS_PROPERTIES,
                                          QLatin1String("PropertiesChanged"),
                                          this,
                                          SLOT(propertiesChanged(QString,QVariantMap,QStringList)));
+
+    qDBusRegisterMetaType<PackageKit::PkPackage>();
+    qDBusRegisterMetaType<QList<PackageKit::PkPackage>>();
+    qDBusRegisterMetaType<PackageKit::PkDetail>();
+    qDBusRegisterMetaType<QList<PackageKit::PkDetail>>();
 }
 
-void DaemonPrivate::setupSignal(const QMetaMethod &signal, bool connect)
+void DaemonPrivate::setupSignal(const QMetaMethod &signal)
 {
     Q_Q(Daemon);
 
@@ -81,11 +150,7 @@ void DaemonPrivate::setupSignal(const QMetaMethod &signal, bool connect)
     }
 
     if (signalToConnect && memberToConnect) {
-        if (connect) {
-            QObject::connect(daemon, signalToConnect, q, memberToConnect);
-        } else {
-            QObject::disconnect(daemon, signalToConnect, q, memberToConnect);
-        }
+        QObject::connect(daemon, signalToConnect, q, memberToConnect);
     }
 }
 
@@ -93,20 +158,14 @@ void Daemon::connectNotify(const QMetaMethod &signal)
 {
     Q_D(Daemon);
     if (!d->connectedSignals.contains(signal) && d->daemon) {
-        d->setupSignal(signal, true);
+        d->setupSignal(signal);
+        d->connectedSignals << signal;
     }
-    d->connectedSignals << signal;
 }
 
 void Daemon::disconnectNotify(const QMetaMethod &signal)
 {
-    Q_D(Daemon);
-    if (d->connectedSignals.contains(signal)) {
-        d->connectedSignals.removeOne(signal);
-        if (d->daemon && !d->connectedSignals.contains(signal)) {
-            d->setupSignal(signal, false);
-        }
-    }
+    QObject::disconnectNotify(signal);
 }
 
 Daemon::~Daemon()
@@ -196,7 +255,7 @@ void Daemon::setHints(const QStringList &hints)
 
 void Daemon::setHints(const QString &hints)
 {
-    global()->d_ptr->hints = QStringList() << hints;
+    global()->d_ptr->hints = QStringList{ hints };
 }
 
 QStringList Daemon::hints()
@@ -219,6 +278,11 @@ QDBusPendingReply<> Daemon::suggestDaemonQuit()
     return global()->d_ptr->daemon->SuggestDaemonQuit();
 }
 
+Offline *Daemon::offline() const
+{
+    return global()->d_ptr->offline;
+}
+
 uint Daemon::versionMajor()
 {
     return global()->d_ptr->versionMajor;
@@ -236,32 +300,27 @@ uint Daemon::versionMicro()
 
 QString Daemon::packageName(const QString &packageID)
 {
-    return packageID.section(QLatin1Char(';'), 0, 0);
+    return Transaction::packageName(packageID);
 }
 
 QString Daemon::packageVersion(const QString &packageID)
 {
-    return packageID.section(QLatin1Char(';'), 1, 1);
+    return Transaction::packageVersion(packageID);
 }
 
 QString Daemon::packageArch(const QString &packageID)
 {
-    return packageID.section(QLatin1Char(';'), 2, 2);
+    return Transaction::packageArch(packageID);
 }
 
 QString Daemon::packageData(const QString &packageID)
 {
-    return packageID.section(QLatin1Char(';'), 3, 3);
-}
-
-QString Daemon::packageIcon(const QString &packageID)
-{
-    return Transaction::packageIcon(packageID);
+    return Transaction::packageData(packageID);
 }
 
 Transaction *Daemon::acceptEula(const QString &eulaId)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleAcceptEula;
     ret->d_ptr->eulaId = eulaId;
     return ret;
@@ -269,7 +328,7 @@ Transaction *Daemon::acceptEula(const QString &eulaId)
 
 Transaction *Daemon::downloadPackages(const QStringList &packageIDs, bool storeInCache)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleDownloadPackages;
     ret->d_ptr->search = packageIDs;
     ret->d_ptr->storeInCache = storeInCache;
@@ -278,19 +337,19 @@ Transaction *Daemon::downloadPackages(const QStringList &packageIDs, bool storeI
 
 Transaction *Daemon::downloadPackage(const QString &packageID, bool storeInCache)
 {
-    return downloadPackages(QStringList() << packageID, storeInCache);
+    return downloadPackages(QStringList{ packageID }, storeInCache);
 }
 
 Transaction *Daemon::getCategories()
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetCategories;
     return ret;
 }
 
 Transaction *Daemon::dependsOn(const QStringList &packageIDs, Transaction::Filters filters, bool recursive)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleDependsOn;
     ret->d_ptr->search = packageIDs;
     ret->d_ptr->filters = filters;
@@ -300,12 +359,12 @@ Transaction *Daemon::dependsOn(const QStringList &packageIDs, Transaction::Filte
 
 Transaction *Daemon::dependsOn(const QString &packageID, Transaction::Filters filters, bool recursive)
 {
-    return dependsOn(QStringList() << packageID, filters, recursive);
+    return dependsOn(QStringList{ packageID }, filters, recursive);
 }
 
 Transaction *Daemon::getDetails(const QStringList &packageIDs)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetDetails;
     ret->d_ptr->search = packageIDs;
     return ret;
@@ -313,12 +372,12 @@ Transaction *Daemon::getDetails(const QStringList &packageIDs)
 
 Transaction *Daemon::getDetails(const QString &packageID)
 {
-    return getDetails(QStringList() << packageID);
+    return getDetails(QStringList{ packageID });
 }
 
 Transaction *Daemon::getDetailsLocal(const QStringList &files)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetDetailsLocal;
     ret->d_ptr->search = files;
     return ret;
@@ -326,12 +385,12 @@ Transaction *Daemon::getDetailsLocal(const QStringList &files)
 
 Transaction *Daemon::getDetailsLocal(const QString &file)
 {
-    return getDetailsLocal(QStringList() << file);
+    return getDetailsLocal(QStringList{ file });
 }
 
 Transaction *Daemon::getFiles(const QStringList &packageIDs)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetFiles;
     ret->d_ptr->search = packageIDs;
     return ret;
@@ -339,12 +398,12 @@ Transaction *Daemon::getFiles(const QStringList &packageIDs)
 
 Transaction *Daemon::getFiles(const QString &packageID)
 {
-    return getFiles(QStringList() << packageID);
+    return getFiles(QStringList{ packageID });
 }
 
 Transaction *Daemon::getFilesLocal(const QStringList &files)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetFilesLocal;
     ret->d_ptr->search = files;
     return ret;
@@ -352,12 +411,12 @@ Transaction *Daemon::getFilesLocal(const QStringList &files)
 
 Transaction *Daemon::getFilesLocal(const QString &file)
 {
-    return getFilesLocal(QStringList() << file);
+    return getFilesLocal(QStringList{ file });
 }
 
 Transaction *Daemon::getOldTransactions(uint number)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetOldTransactions;
     ret->d_ptr->numberOfOldTransactions = number;
     return ret;
@@ -365,7 +424,7 @@ Transaction *Daemon::getOldTransactions(uint number)
 
 Transaction *Daemon::getPackages(Transaction::Filters filters)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetPackages;
     ret->d_ptr->filters = filters;
     return ret;
@@ -373,7 +432,7 @@ Transaction *Daemon::getPackages(Transaction::Filters filters)
 
 Transaction *Daemon::getRepoList(Transaction::Filters filters)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetRepoList;
     ret->d_ptr->filters = filters;
     return ret;
@@ -381,7 +440,7 @@ Transaction *Daemon::getRepoList(Transaction::Filters filters)
 
 Transaction *Daemon::requiredBy(const QStringList &packageIDs, Transaction::Filters filters, bool recursive)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleRequiredBy;
     ret->d_ptr->search = packageIDs;
     ret->d_ptr->filters = filters;
@@ -391,12 +450,12 @@ Transaction *Daemon::requiredBy(const QStringList &packageIDs, Transaction::Filt
 
 Transaction *Daemon::requiredBy(const QString &packageID, Transaction::Filters filters, bool recursive)
 {
-    return requiredBy(QStringList() << packageID, filters, recursive);
+    return requiredBy(QStringList{ packageID }, filters, recursive);
 }
 
 Transaction *Daemon::getUpdatesDetails(const QStringList &packageIDs)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetUpdateDetail;
     ret->d_ptr->search = packageIDs;
     return ret;
@@ -404,12 +463,12 @@ Transaction *Daemon::getUpdatesDetails(const QStringList &packageIDs)
 
 Transaction *Daemon::getUpdateDetail(const QString &packageID)
 {
-    return getUpdatesDetails(QStringList() << packageID);
+    return getUpdatesDetails(QStringList{ packageID });
 }
 
 Transaction *Daemon::getUpdates(Transaction::Filters filters)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetUpdates;
     ret->d_ptr->filters = filters;
     return ret;
@@ -417,14 +476,24 @@ Transaction *Daemon::getUpdates(Transaction::Filters filters)
 
 Transaction *Daemon::getDistroUpgrades()
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleGetDistroUpgrades;
     return ret;
 }
 
+Transaction *Daemon::upgradeSystem(const QString &distroId, Transaction::UpgradeKind kind, Transaction::TransactionFlags flags)
+{
+    auto ret = new Transaction;
+    ret->d_ptr->role = Transaction::RoleUpgradeSystem;
+    ret->d_ptr->upgradeDistroId = distroId;
+    ret->d_ptr->upgradeKind = kind;
+    ret->d_ptr->transactionFlags = flags;
+    return ret;
+}
+
 Transaction *Daemon::installFiles(const QStringList &files, Transaction::TransactionFlags flags)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleInstallFiles;
     ret->d_ptr->search = files;
     ret->d_ptr->transactionFlags = flags;
@@ -433,12 +502,12 @@ Transaction *Daemon::installFiles(const QStringList &files, Transaction::Transac
 
 Transaction *Daemon::installFile(const QString &file, Transaction::TransactionFlags flags)
 {
-    return installFiles(QStringList() << file, flags);
+    return installFiles(QStringList{ file }, flags);
 }
 
 Transaction *Daemon::installPackages(const QStringList &packageIDs, Transaction::TransactionFlags flags)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleInstallPackages;
     ret->d_ptr->search = packageIDs;
     ret->d_ptr->transactionFlags = flags;
@@ -447,12 +516,12 @@ Transaction *Daemon::installPackages(const QStringList &packageIDs, Transaction:
 
 Transaction *Daemon::installPackage(const QString &packageID, Transaction::TransactionFlags flags)
 {
-    return installPackages(QStringList() << packageID, flags);
+    return installPackages(QStringList{ packageID }, flags);
 }
 
 Transaction *Daemon::installSignature(Transaction::SigType type, const QString &keyID, const QString &packageID)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleInstallSignature;
     ret->d_ptr->signatureType = type;
     ret->d_ptr->signatureKey = keyID;
@@ -462,7 +531,7 @@ Transaction *Daemon::installSignature(Transaction::SigType type, const QString &
 
 Transaction *Daemon::refreshCache(bool force)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleRefreshCache;
     ret->d_ptr->refreshCacheForce = force;
     return ret;
@@ -470,7 +539,7 @@ Transaction *Daemon::refreshCache(bool force)
 
 Transaction *Daemon::removePackages(const QStringList &packageIDs, bool allowDeps, bool autoremove, Transaction::TransactionFlags flags)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleRemovePackages;
     ret->d_ptr->search = packageIDs;
     ret->d_ptr->allowDeps = allowDeps;
@@ -481,12 +550,12 @@ Transaction *Daemon::removePackages(const QStringList &packageIDs, bool allowDep
 
 Transaction *Daemon::removePackage(const QString &packageID, bool allowDeps, bool autoremove, Transaction::TransactionFlags flags)
 {
-    return removePackages(QStringList() << packageID, allowDeps, autoremove, flags);
+    return removePackages(QStringList{ packageID }, allowDeps, autoremove, flags);
 }
 
 Transaction *Daemon::repairSystem(Transaction::TransactionFlags flags)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleRepairSystem;
     ret->d_ptr->transactionFlags = flags;
     return ret;
@@ -494,7 +563,7 @@ Transaction *Daemon::repairSystem(Transaction::TransactionFlags flags)
 
 Transaction *Daemon::repoEnable(const QString &repoId, bool enable)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleRepoEnable;
     ret->d_ptr->repoId = repoId;
     ret->d_ptr->repoEnable = enable;
@@ -503,7 +572,7 @@ Transaction *Daemon::repoEnable(const QString &repoId, bool enable)
 
 Transaction *Daemon::repoRemove(const QString &repoId, bool autoremove, Transaction::TransactionFlags flags)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleRepoRemove;
     ret->d_ptr->repoId = repoId;
     ret->d_ptr->autoremove = autoremove;
@@ -513,7 +582,7 @@ Transaction *Daemon::repoRemove(const QString &repoId, bool autoremove, Transact
 
 Transaction *Daemon::repoSetData(const QString &repoId, const QString &parameter, const QString &value)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleRepoSetData;
     ret->d_ptr->repoId = repoId;
     ret->d_ptr->repoParameter = parameter;
@@ -523,7 +592,7 @@ Transaction *Daemon::repoSetData(const QString &repoId, const QString &parameter
 
 Transaction *Daemon::resolve(const QStringList &packageNames, Transaction::Filters filters)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleResolve;
     ret->d_ptr->search = packageNames;
     ret->d_ptr->filters = filters;
@@ -532,12 +601,12 @@ Transaction *Daemon::resolve(const QStringList &packageNames, Transaction::Filte
 
 Transaction *Daemon::resolve(const QString &packageName, Transaction::Filters filters)
 {
-    return resolve(QStringList() << packageName, filters);
+    return resolve(QStringList{ packageName }, filters);
 }
 
 Transaction *Daemon::searchFiles(const QStringList &search, Transaction::Filters filters)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleSearchFile;
     ret->d_ptr->search = search;
     ret->d_ptr->filters = filters;
@@ -546,12 +615,12 @@ Transaction *Daemon::searchFiles(const QStringList &search, Transaction::Filters
 
 Transaction *Daemon::searchFiles(const QString &search, Transaction::Filters filters)
 {
-    return searchFiles(QStringList() << search, filters);
+    return searchFiles(QStringList{ search }, filters);
 }
 
 Transaction *Daemon::searchDetails(const QStringList &search, Transaction::Filters filters)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleSearchDetails;
     ret->d_ptr->search = search;
     ret->d_ptr->filters = filters;
@@ -560,12 +629,12 @@ Transaction *Daemon::searchDetails(const QStringList &search, Transaction::Filte
 
 Transaction *Daemon::searchDetails(const QString &search, Transaction::Filters filters)
 {
-    return searchDetails(QStringList() << search, filters);
+    return searchDetails(QStringList{ search }, filters);
 }
 
 Transaction *Daemon::searchGroups(const QStringList &groups, Transaction::Filters filters)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleSearchGroup;
     ret->d_ptr->search = groups;
     ret->d_ptr->filters = filters;
@@ -574,7 +643,7 @@ Transaction *Daemon::searchGroups(const QStringList &groups, Transaction::Filter
 
 Transaction *Daemon::searchGroup(const QString &group, Transaction::Filters filters)
 {
-    return searchGroups(QStringList() << group, filters);
+    return searchGroups(QStringList{ group }, filters);
 }
 
 Transaction *Daemon::searchGroup(Transaction::Group group, Transaction::Filters filters)
@@ -599,7 +668,7 @@ Transaction *Daemon::searchGroups(Transaction::Groups groups, Transaction::Filte
 
 Transaction *Daemon::searchNames(const QStringList &search, Transaction::Filters filters)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleSearchName;
     ret->d_ptr->search = search;
     ret->d_ptr->filters = filters;
@@ -608,12 +677,12 @@ Transaction *Daemon::searchNames(const QStringList &search, Transaction::Filters
 
 Transaction *Daemon::searchNames(const QString &search, Transaction::Filters filters)
 {
-    return searchNames(QStringList() << search, filters);
+    return searchNames(QStringList{ search }, filters);
 }
 
 Transaction *Daemon::updatePackages(const QStringList &packageIDs, Transaction::TransactionFlags flags)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleUpdatePackages;
     ret->d_ptr->search = packageIDs;
     ret->d_ptr->transactionFlags = flags;
@@ -622,12 +691,12 @@ Transaction *Daemon::updatePackages(const QStringList &packageIDs, Transaction::
 
 Transaction *Daemon::updatePackage(const QString &packageID, Transaction::TransactionFlags flags)
 {
-    return updatePackages(QStringList() << packageID, flags);
+    return updatePackages(QStringList{ packageID }, flags);
 }
 
 Transaction *Daemon::whatProvides(const QStringList &search, Transaction::Filters filters)
 {
-    Transaction *ret = new Transaction;
+    auto ret = new Transaction;
     ret->d_ptr->role = Transaction::RoleWhatProvides;
     ret->d_ptr->search = search;
     ret->d_ptr->filters = filters;
@@ -636,7 +705,7 @@ Transaction *Daemon::whatProvides(const QStringList &search, Transaction::Filter
 
 Transaction *Daemon::whatProvides(const QString &search, Transaction::Filters filters)
 {
-    return whatProvides(QStringList() << search, filters);
+    return whatProvides(QStringList{ search }, filters);
 }
 
 QString Daemon::enumToString(const QMetaObject &metaObject, int value, const char *enumName)
